==> Musicreater-0.2.3.tar.gz: Musicreater-0.2.3/README.md <==
<h1 align="center">音·创 Musicreater</h1>

<p align="center">
<img width="128" height="128" src="https://s1.ax1x.com/2022/05/06/Ouhghj.md.png" >
</p>

<h3 align="center">一个免费开源的《我的世界：基岩版》音乐编辑制作软件</h3>

<p align="center">
<img src="https://forthebadge.com/images/badges/built-with-love.svg">
<p>


[![][Bilibili: 凌云金羿]](https://space.bilibili.com/397369002/)
[![][Bilibili: 诸葛亮与八卦阵]](https://space.bilibili.com/604072474) 
[![CodeStyle: black]](https://github.com/psf/black)
[![][python]](https://www.python.org/)
[![][license]](LICENSE)
[![][release]](../../releases)


简体中文 | [English](README_EN.md)


## 介绍🚀

音·创 是一个免费开源的针对 **《我的世界》** 的midi音乐转换库

欢迎加群：[861684859](https://jq.qq.com/?_wv=1027&k=hpeRxrYr)

### 目前版本 Current version: 0.2.3 

## 文档📄

[生成文件的使用](./docs/%E7%94%9F%E6%88%90%E6%96%87%E4%BB%B6%E7%9A%84%E4%BD%BF%E7%94%A8%E8%AF%B4%E6%98%8E.md)

[仓库API文档](./docs/%E5%BA%93%E7%9A%84%E7%94%9F%E6%88%90%E4%B8%8E%E5%8A%9F%E8%83%BD%E6%96%87%E6%A1%A3.md)

## 作者✒

金羿 Eilles：我的世界基岩版指令师，个人开发者，B站不知名UP主，江西在校高中生。

诸葛亮与八卦阵 bgArray：我的世界基岩版玩家，喜欢编程和音乐，深圳初二学生。

## 致谢🙏
本致谢列表排名无顺序。

- 感谢 **昀梦**\<QQ1515399885\> 找出指令生成错误bug并指正
- 感谢由 **Charlie_Ping “查理平”** 带来的BDX文件转换参考，以及MIDI-我的世界对应乐器参考表格
- 感谢由 **[CMA_2401PT](https://github.com/CMA2401PT)** 为我们的软件开发的一些方面进行指导，同时我们参考了他的BDXworkshop作为BDX结构编辑的参考
- 感谢由 **[Dislink Sforza](https://github.com/Dislink) “断联·斯福尔扎”**\<QQ1600515314\> 带来的midi音色解析以及转换指令的算法，我们将其改编并应用；同时，感谢他的[网页版转换器](https://dislink.github.io/midi2bdx/)给我们的开发与更新带来巨大的压力和动力，让我们在原本一骑绝尘的摸鱼道路上转向开发，希望他能考上一个理想的大学！
- 感谢 **Touch “偷吃”**\<QQ1793537164\> 提供的BDX导入测试支持，并对程序的改进提供了丰富的意见；同时也感谢他的不断尝试新的内容，使我们的排错更进一步
- 感谢 **Mono**\<QQ738893087\> 反馈安装时的问题，辅助我们找到了视窗操作系统下的兼容性问题
- 感谢 **Ammelia “艾米利亚”**\<QQ2838334637\> 敦促我们进行新的功能开发，并为新功能提出了非常优秀的大量建议，以及提供的BDX导入测试支持，为我们的新结构生成算法提供了大量的实际理论支持
- 感谢 **[神羽](https://gitee.com/snowykami) “[SnowyKami](https://github.com/snowyfirefly)”** 对我们项目的支持与宣传
- 感谢 **指令师_苦力怕 playjuice123**\<QQ240667197\>为我们的程序找出错误，并提醒我们修复一个一直存在的大bug。
- 感谢 **雷霆**\<QQ3555268519\>为我们的程序找出错误，并提醒修复bug。

>	感谢广大群友为此程序提供的测试等支持
>
>	若您对我们有所贡献但您的名字没有显示在此列表中，请联系我们！

## 联系📞

若遇到库中的问题，欢迎在[此](https://gitee.com/TriM-Organization/Musicreater/issues/new)提出你的issue。

如果需要与开发组进行交流，欢迎加入我们的[开发闲聊Q群](https://jq.qq.com/?_wv=1027&k=hpeRxrYr)。



[Bilibili: 凌云金羿]: https://img.shields.io/badge/Bilibili-%E5%87%8C%E4%BA%91%E9%87%91%E7%BE%BF-00A1E7?style=for-the-badge
[Bilibili: 诸葛亮与八卦阵]: https://img.shields.io/badge/Bilibili-%E8%AF%B8%E8%91%9B%E4%BA%AE%E4%B8%8E%E5%85%AB%E5%8D%A6%E9%98%B5-00A1E7?style=for-the-badge
[CodeStyle: black]: https://img.shields.io/badge/code%20style-black-121110.svg?style=for-the-badge
[python]: https://img.shields.io/badge/python-3.6-AB70FF?style=for-the-badge
[release]: https://img.shields.io/github/v/release/EillesWan/Musicreater?style=for-the-badge
[license]: https://img.shields.io/badge/Licence-Apache-228B22?style=for-the-badge

==> Musicreater-0.2.9.tar.gz: Musicreater-0.2.9/README.md <==
<h1 align="center">音·创 Musicreater</h1>

<p align="center">
<img width="128" height="128" src="https://s1.ax1x.com/2022/05/06/Ouhghj.md.png" >
</p>

<h3 align="center">一个免费开源的《我的世界：基岩版》音乐编辑制作软件</h3>

<p align="center">
<img src="https://forthebadge.com/images/badges/built-with-love.svg">
<p>


[![][Bilibili: 凌云金羿]](https://space.bilibili.com/397369002/)
[![][Bilibili: 诸葛亮与八卦阵]](https://space.bilibili.com/604072474) 
[![CodeStyle: black]](https://github.com/psf/black)
[![][python]](https://www.python.org/)
[![][license]](LICENSE)
[![][release]](../../releases)


简体中文🇨🇳 | [English🇬🇧](README_EN.md)


## 介绍🚀

音·创 是一个免费开源的针对 **《我的世界》** 的midi音乐转换库

欢迎加群：[861684859](https://jq.qq.com/?_wv=1027&k=hpeRxrYr)

## 下载安装

-   使用pypi
    ```bash
    pip install Musicreater
    ```

-   克隆仓库
    ```bash
    git clone https://gitee.com/TriM-Organization/Musicreater.git
    cd Musicreater
    python setup.py install
    ```

以上命令种 `python`、`pip` 请依照各个环境不同灵活更换，可能为`python3`或`pip3`之类。

## 文档📄

[生成文件的使用](./docs/%E7%94%9F%E6%88%90%E6%96%87%E4%BB%B6%E7%9A%84%E4%BD%BF%E7%94%A8%E8%AF%B4%E6%98%8E.md)

[仓库API文档](./docs/%E5%BA%93%E7%9A%84%E7%94%9F%E6%88%90%E4%B8%8E%E5%8A%9F%E8%83%BD%E6%96%87%E6%A1%A3.md)

## 作者✒

金羿 Eilles：我的世界基岩版指令师，个人开发者，B站不知名UP主，江西在校高中生。

诸葛亮与八卦阵 bgArray：我的世界基岩版玩家，喜欢编程和音乐，深圳初二学生。

## 致谢🙏
本致谢列表排名无顺序。

- 感谢 **昀梦**\<QQ1515399885\> 找出指令生成错误bug并指正
- 感谢由 **Charlie_Ping “查理平”** 带来的BDX文件转换参考，以及MIDI-我的世界对应乐器参考表格
- 感谢由 **[CMA_2401PT](https://github.com/CMA2401PT)** 为我们的软件开发的一些方面进行指导，同时我们参考了他的BDXworkshop作为BDX结构编辑的参考
- 感谢由 **[Dislink Sforza](https://github.com/Dislink) “断联·斯福尔扎”**\<QQ1600515314\> 带来的midi音色解析以及转换指令的算法，我们将其改编并应用；同时，感谢他的[网页版转换器](https://dislink.github.io/midi2bdx/)给我们的开发与更新带来巨大的压力和动力，让我们在原本一骑绝尘的摸鱼道路上转向开发，希望他能考上一个理想的大学！
- 感谢 **Touch “偷吃”**\<QQ1793537164\> 提供的BDX导入测试支持，并对程序的改进提供了丰富的意见；同时也感谢他的不断尝试新的内容，使我们的排错更进一步
- 感谢 **Mono**\<QQ738893087\> 反馈安装时的问题，辅助我们找到了视窗操作系统下的兼容性问题
- 感谢 **Ammelia “艾米利亚”**\<QQ2838334637\> 敦促我们进行新的功能开发，并为新功能提出了非常优秀的大量建议，以及提供的BDX导入测试支持，为我们的新结构生成算法提供了大量的实际理论支持
- 感谢 **[神羽](https://gitee.com/snowykami) “[SnowyKami](https://github.com/snowyfirefly)”** 对我们项目的支持与宣传
- 感谢 **指令师_苦力怕 playjuice123**\<QQ240667197\>为我们的程序找出错误，并提醒我们修复一个一直存在的大bug。
- 感谢 **雷霆**\<QQ3555268519\>为我们的程序找出错误，并提醒修复bug。

>	感谢广大群友为此程序提供的测试等支持
>
>	若您对我们有所贡献但您的名字没有显示在此列表中，请联系我们！

## 联系📞

若遇到库中的问题，欢迎在[此](https://gitee.com/TriM-Organization/Musicreater/issues/new)提出你的issue。

如果需要与开发组进行交流，欢迎加入我们的[开发闲聊Q群](https://jq.qq.com/?_wv=1027&k=hpeRxrYr)。



[Bilibili: 凌云金羿]: https://img.shields.io/badge/Bilibili-%E5%87%8C%E4%BA%91%E9%87%91%E7%BE%BF-00A1E7?style=for-the-badge
[Bilibili: 诸葛亮与八卦阵]: https://img.shields.io/badge/Bilibili-%E8%AF%B8%E8%91%9B%E4%BA%AE%E4%B8%8E%E5%85%AB%E5%8D%A6%E9%98%B5-00A1E7?style=for-the-badge
[CodeStyle: black]: https://img.shields.io/badge/code%20style-black-121110.svg?style=for-the-badge
[python]: https://img.shields.io/badge/python-3.6-AB70FF?style=for-the-badge
[release]: https://img.shields.io/github/v/release/EillesWan/Musicreater?style=for-the-badge
[license]: https://img.shields.io/badge/Licence-Apache-228B22?style=for-the-badge
